/* vi: set sw=4 ts=4: */
/*
 * eventfd() for uClibc
 *
 * Copyright (C) 2011 Jean-Christian de Rivaz <jc@eclis.ch>
 *
 * Licensed under the LGPL v2.1, see the file COPYING.LIB in this tarball.
 */

#include <errno.h>
#include <unistd.h>
#include <stdint.h>
#include <syscall.h>


/* Get the platform-dependent flags.  */
/* Flags for eventfd.  */
enum
  {
    EFD_SEMAPHORE = 00000001,
#define EFD_SEMAPHORE EFD_SEMAPHORE
    EFD_CLOEXEC = 02000000,
#define EFD_CLOEXEC EFD_CLOEXEC
    EFD_NONBLOCK = 00004000
#define EFD_NONBLOCK EFD_NONBLOCK
  };
/* Type for event counter.  */
typedef uint64_t eventfd_t;

/*
 * eventfd()
 */

int eventfd (unsigned int count, int flags)
{
  return syscall(SYS_eventfd2,count,flags);
}

int
eventfd_read (int fd, eventfd_t *value)
{
  return read (fd, value, sizeof (eventfd_t)) != sizeof (eventfd_t) ? -1 : 0;
}


int
eventfd_write (int fd, eventfd_t value)
{
  return write (fd, &value,
	sizeof (eventfd_t)) != sizeof (eventfd_t) ? -1 : 0;
}

